@@ -2,7 +2,10 @@ extern crate gcode;
 
 use gcode::Mnemonic;
 
-const PROGRAM_1: &str = include_str!(concat!(env!("CARGO_MANIFEST_DIR"), "/tests/data/program_1.gcode"));
+const PROGRAM_1: &str = include_str!(concat!(
+    env!("CARGO_MANIFEST_DIR"),
+    "/tests/data/program_1.gcode"
+));
 
 fn main() {
     let mut g_codes = 0;
@@ -14,7 +17,7 @@ fn main() {
         println!("{:#?}", block);
 
         match block.mnemonic() {
-            Mnemonic ::General => g_codes += 1,
+            Mnemonic::General => g_codes += 1,
             Mnemonic::MachineRoutine => m_codes += 1,
             _ => {}
         }
